CryptoObject class abstract

Abstract class representing a cryptographic object for biometric authentication.

This is required for Android authentication to ensure security compliance and prevent warnings from static analysis tools like Ostorlab.

Implementers

Constructors

CryptoObject.forCipher({required String keyAlias, required Uint8List data, required CryptoOperation mode})
Factory constructor for creating an encryption/decryption crypto object.
factory
CryptoObject.forEncryption({required String keyAlias, required Uint8List data, required CryptoOperation mode})
Factory constructor for creating an encryption/decryption crypto object.
factory
CryptoObject.forSignature({required String keyAlias, required Uint8List data})
Factory constructor for creating a signature crypto object.
factory

Properties

canDecrypt bool
Whether this crypto object can perform decryption operations.
no setter
canEncrypt bool
Whether this crypto object can perform encryption operations.
no setter
canSign bool
Whether this crypto object can perform signing operations.
no setter
data Uint8List?
Data to be used in the cryptographic operation (optional).
no setter
hashCode int
The hash code for this object.
no setterinherited
keyAlias String
Key alias used for cryptographic operations.
no setter
operation CryptoOperation
The cryptographic operation this object is configured for.
no setter
platformObject → dynamic
Platform-specific implementation object.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited