KeychainPermissionException class

Exception thrown when there are insufficient permissions for keychain operations.

Inheritance

Constructors

KeychainPermissionException(String message, int osStatus)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
osStatus int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited