KeychainResult class

Result of a keychain operation.

Constructors

KeychainResult({required bool success, String? storedDataKey, Uint8List? retrievedData, String? error})
Constructs a new instance.
const
KeychainResult.failure({required String error})
Factory constructor for a failed operation.
factory
KeychainResult.retrievalSuccess({required Uint8List retrievedData})
Factory constructor for a successful retrieval operation.
factory
KeychainResult.storageSuccess({required String storedDataKey})
Factory constructor for a successful storage operation.
factory

Properties

error String?
Error message if operation failed.
final
hashCode int
The hash code for this object.
no setterinherited
retrievedData Uint8List?
Retrieved data (if retrieval operation).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storedDataKey String?
Key for the stored data (if storage operation).
final
success bool
Whether the operation was successful.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited