MigrationPriority enum

Priority level for migration suggestions.

Inheritance
Available extensions

Values

critical → const MigrationPriority

Critical: Must be fixed for the app to work

high → const MigrationPriority

High: Important for security or functionality

medium → const MigrationPriority

Medium: Recommended for best practices

low → const MigrationPriority

Low: Optional improvements

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MigrationPriority>
A constant List of the values in this enum, in order of their declaration.