MigrationSuggestion class

Suggestion for migrating from local_auth to better_local_auth.

Constructors

MigrationSuggestion({required String description, required String codeExample, required MigrationPriority priority})
Constructs a new instance.
const

Properties

codeExample String
Code example showing how to implement the suggestion.
final
description String
Description of the migration suggestion.
final
hashCode int
The hash code for this object.
no setterinherited
priority MigrationPriority
Priority level of the suggestion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited