local_auth library

Classes

AndroidAuthMessages
Android specific authentication messages.
AndroidCryptoObject
Android-specific implementation of CryptoObject.
AuthMessages
Abstract class for storing platform specific strings.
AuthResult
Enhanced authentication result with additional information.
BetterLocalAuthentication
Enhanced Flutter plugin for authenticating the user identity locally with required cryptoObject support for Android security compliance.
CryptoObject
Abstract class representing a cryptographic object for biometric authentication.
IOSAuthMessages
iOS specific authentication messages.
iOSKeychainCryptoObject
iOS-specific implementation of CryptoObject using Keychain.
KeychainOptions
Options for iOS keychain integration.
KeychainResult
Result of a keychain operation.
LocalAuthentication
A Flutter plugin for authenticating the user identity locally.
MigrationAnalysis
Analysis of current local_auth usage in source code.
MigrationHelper
Helper class for migrating from local_auth to better_local_auth.
MigrationSuggestion
Suggestion for migrating from local_auth to better_local_auth.

Enums

BiometricType
Various types of biometric authentication. Some platforms report specific biometric types, while others report only classifications like strong and weak.
CryptoOperation
Enum representing cryptographic operations that can be performed.
KeychainAccessibility
Enum representing iOS keychain accessibility levels.
LocalAuthExceptionCode
Types of LocalAuthExceptions, as indicated by LocalAuthException.code.
MigrationPriority
Priority level for migration suggestions.

Exceptions / Errors

CryptoObjectCreationException
Exception thrown when CryptoObject creation fails.
CryptoObjectException
Exception thrown when there is an error with CryptoObject operations.
CryptoObjectOperationException
Exception thrown when CryptoObject operation fails.
CryptoObjectValidationException
Exception thrown when CryptoObject validation fails.
KeychainException
Exception thrown when there is an error with Keychain operations.
KeychainPermissionException
Exception thrown when there are insufficient permissions for keychain operations.
KeychainRetrievalException
Exception thrown when keychain retrieval fails.
KeychainStorageException
Exception thrown when keychain storage fails.
LocalAuthException
An exception thrown by the plugin when there is authentication failure, or some other error.